# Qt5 Example

This example demonstrates how to compile Qt5 applications with Craftr.

__Important__:

Before you can build this example, you must first update the `.craftrconfig`
file and make sure the `craftr.lib.qt5.dir` option points to the directory
containing your installation of Qt5 prebuilt binaries and headers.

__Building__:

    $ craftr export
    $ craftr build run

__Screenshot__:

![Screenshot](https://i.imgur.com/kBUpvNR.png)
